The Sentry Debug Images Integration.
The DebugImagesIntegration adds metadata about the loaded shared
libraries to Sentry Events.
This Integration only works on Unix-like OSs right now. Support for Windows will be added in the future.
Configuration
The integration by default attaches this information to all Events, but
a custom filter can be defined as well.
use ckb_sentry_debug_images as sentry_debug_images;
use sentry_core::Level;
let integration = sentry_debug_images::DebugImagesIntegration::new()
.filter(|event| event.level >= Level::Warning);Structs
- Debug
Images Integration - The Sentry Debug Images Integration.